DntFileObjectStore

Struct DntFileObjectStore 

pub struct DntFileObjectStore<'a, K, C> { /* private fields */ }
DNT adapter over the local file storage provider.

Implementations

Source

impl<'a, K, C> DntFileObjectStore<'a, K, C>
where K: DntKeyProvider, C: DntCodec,

pub fn new( provider: &'a FileStorageProvider, key_provider: &'a K, codec: C, policy: SealedStoragePolicy, ) -> Self

Creates a sealed object store over an existing file provider.

pub fn write_object_compact( &self, path: &str, payload: &[u8], ) -> StorageResult<()>

Seals, compacts and atomically writes an object.

Compact writes use DNT’s authenticated DEFLATE payload flag. Existing readers open compact and normal envelopes through the same read_object path as long as they provide a payload bound.